<?php

switch ($messaggio) {

case "Configura e personalizza HotelDruid":	$messaggio = "Configurer et personnaliser HotelDruid"; break;
case "Scegli la lingua":  							$messaggio = "Choisir la langue"; break;
case "cambia la lingua":  							$messaggio = "Changer la langue"; break;
case "Tabella con tutte le prenotazioni":  			$messaggio = "Tableau avec toutes les réservations"; break;
case "Cambia la valuta":  							$messaggio = "Changer la devise"; break;
case "Scegli le colonne da far comparire":  		$messaggio = "Choisir les colonnes à faire apparaître"; break;
case "n° di settimane":  							$messaggio = "n° de semaines"; break;
case "n° di giorni":  								$messaggio = "nombre de jours"; break;
case "caparra":  									$messaggio = "Arrhes"; break;
case "pagato":  									$messaggio = "payé"; break;
case "resto da pagare":  							$messaggio = "reste à payer"; break;
case "n° di persone":  								$messaggio = "nombre de personnes"; break;
case "commento":  									$messaggio = "commentaire"; break;
case "costo aggiuntivo unico":  					$messaggio = "surcoût unique"; break;
case "abbreviazione":  								$messaggio = "abréviation"; break;
case "costo aggiuntivo settimanale":  				$messaggio = "Surcoût hebdomadaire"; break;
case "costo aggiuntivo giornaliero":  				$messaggio = "Surcoût journalier"; break;
case "cambia le colonne":  							$messaggio = "Changer les colonnes"; break;
case "Tabelle dei mesi":  							$messaggio = "Tableau des mois"; break;
case "Numero di tabelle del 2° tipo":  				$messaggio = "Nombre de tableaux du 2° type"; break;
case "cambia":  									$messaggio = "changer"; break;
case "Torna al menù principale":  					$messaggio = "Retour au menu principal"; break;
case "a":  											$messaggio = "à"; break;
case "La lingua è stata cambiata":  				$messaggio = "La langue a été changée"; break;
case "La valuta è stata cambiata":  				$messaggio = "La devise a été changée"; break;
case "Le colonne sono state cambiate":  			$messaggio = "Les colonnes ont été changées"; break;
case "Il numero di tabelle è stato cambiato":  		$messaggio = "Le nombre de tableaux a été changé"; break;
case "cambia i nomi dei documenti":  		$messaggio = "changer les noms des documents"; break;
case "I nomi dei documenti sono stati cambiati":	$messaggio = "Les noms des documents ont été changés"; break;
case "Formato di visualizzazione dei soldi":  		$messaggio = "Format de la monnaie"; break;
case "cambia formato":  							$messaggio = "changer le format"; break;
case "Il formato di visualizzazione dei soldi è stato cambiato":	$messaggio = "Le format de la monnaie a été changé"; break;
case "Le date sono sbagliate":  					$messaggio = "Les dates sont erronées"; break;
case "Le date dei menù a tendina sono state cambiate":	$messaggio = "Les dates des menus déroulants ont été changées"; break;
case "Scegli le date":  							$messaggio = "Choisir les dates"; break;
case "nei menù a tendina":  						$messaggio = "dans les menus déroulants"; break;
case "dal":  										$messaggio = "de"; break;
case "al":  										$messaggio = "à"; break;
case "Tronca i cognomi nelle tabelle dopo ":		$messaggio = "Tronquer le nom de famille après "; break;
case "caratteri per colonna":  						$messaggio = "caractères par colonne"; break;
case "La lunghezza dei cognomi nelle tabelle dei mesi è stata cambiata":	$messaggio = "La longueur des noms de famille dans les tables des mois a été changée"; break;
case "Cambia il numero delle tariffe":  			$messaggio = "Changer le nombre de tarifs"; break;
case "per l'anno":  								$messaggio = "pour l'année"; break;
case "Il numero delle tariffe è stato cambiato":	$messaggio = "Le nombre de tarifs a été changé"; break;
case "Il numero di tariffe è sbagliato":  			$messaggio = "Le nombre de tarifs est erroné"; break;
case "Sistema di backup":  							$messaggio = "Système de sauvegarde"; break;
case "Il numero delle righe è sbagliato":  			$messaggio = "Le nombre de rangées est erroné"; break;
case "Cambia il numero delle righe":  				$messaggio = "Changer le nombre de rangées"; break;
case "Il numero delle righe della tabella con tutte le prenotazioni è stato cambiato":					$messaggio = "Le nombre de rangées du tableau avec toutes les réservations  a été changé"; break;
case "Il numero delle righe della tabella con la storia delle entrate e delle uscite è stato cambiato":	$messaggio = "Le nombre de rangées du tableau de l'historique des paiements a été changé"; break;
case "Tabella con la storia delle entate e uscite":														$messaggio = "Tableau de l'historique des paiements"; break;
case "Il formato di visualizzazione delle date è stato cambiato":										$messaggio = "Format d'affichage des dates a été changé"; break;
case "Formato di visualizzazione delle date":		$messaggio = "Format d'affichage des dates"; break;
case "Tabella con tutti i clienti":  				$messaggio = "Tableau avec tous les clients"; break;
case "Il numero delle righe della tabella con tutti i clienti è stato cambiato":	$messaggio = "Le nombre de rangées de la table avec tous les clients a été changé"; break;
case "Si deve sceliere qualche dato da inserire nella colonna gruppo":				$messaggio = "Vous devez choisir quelles données insérer dans le groupe de colonnes"; break;
case "Si deve inserire il nome della colonna gruppo":								$messaggio = "Vous devez choisir un nom au groupe de colonnes"; break;
case "La colonna gruppo è stata aggiunta":  		$messaggio = "La colonne de groupe a été ajoutée"; break;
case "Aggiungi una colonna gruppo":  				$messaggio = "Ajouter une colonne groupe"; break;
case "Aggiungi colonna gruppo":  					$messaggio = "Ajouter la colonne de groupe"; break;
case "chiamata":  									$messaggio = "appelé"; break;
case "con":  										$messaggio = "avec"; break;
case "colonna gruppo":  							$messaggio = "groupe colonne"; break;
case "separatore":  								$messaggio = "séparateur"; break;
case "spazio":  									$messaggio = "espace"; break;
case "trattino":  									$messaggio = "tiret"; break;
case "a capo":  									$messaggio = "nouvelle ligne"; break;
case "Pagine per il sito web":  		$messaggio = "Pages site web"; break;
case " Do":  										$messaggio = " Di"; break;
case " Lu":  										$messaggio = " Lu"; break;
case " Ma":  										$messaggio = " Ma"; break;
case " Me":  										$messaggio = " Me"; break;
case " Gi":  										$messaggio = " Jd"; break;
case " Ve":  										$messaggio = " Vd"; break;
case " Sa":  										$messaggio = " Sa"; break;
case "Gen":  										$messaggio = "Jan"; break;
case "Feb":  										$messaggio = "Fév"; break;
case "Mar":  										$messaggio = "Mars"; break;
case "Apr":  					$messaggio = "Apr"; break;
case "Mag":  										$messaggio = "Mai"; break;
case "Giu":  										$messaggio = "Juin"; break;
case "Lug":  										$messaggio = "Juil"; break;
case "Ago":  										$messaggio = "Août"; break;
case "Set":  										$messaggio = "Sep"; break;
case "Ott":  										$messaggio = "Oct"; break;
case "Nov":  										$messaggio = "Nov"; break;
case "Dic":  										$messaggio = "Déc"; break;
case "nome della tariffa":  						$messaggio = "nom du tarif"; break;
case "data di inserimento":  						$messaggio = "date d'insertion"; break;
case "tariffa completa":  							$messaggio = "tarif complet"; break;
case "Gestione utenti":  							$messaggio = "Gestion utilsateurs"; break;
case "Personalizzazioni dell'utente":  				$messaggio = "Personnalisations de l'utilisateur"; break;
case "Cambia":  									$messaggio = "Changer"; break;
case "quelle di":  									$messaggio = "ceux de"; break;
case "Importa i nomi dei documenti":  		$messaggio = "Importer les noms des documents"; break;
case "Importa":  									$messaggio = "Importer"; break;
case "dell'utente":  								$messaggio = "de l'utilisateur"; break;
case "I minuti di durata di sessioni e transazioni sono stati cambiati":							$messaggio = "La durée en minutes des réservations et transactions non mises à jour a été changée"; break;
case "Le ore di anticipo dell'inizio delle prenotazioni sono state cambiate":						$messaggio = "Nombre d'heures à prévoir pour considerer le moment des réservations commencé a été changée"; break;
case "Minuti dopo i quali considerare scadute sessioni e transazioni non aggiornate":				$messaggio = "Minutes après lesquelles sont considerées expirées les réservations et transactions non mises à jour "; break;
case "Numero di ore di cui anticipare il momento in cui si considera iniziata una prenotazione":	$messaggio = "Nombre d'heures à prévoir pour considerer le moment des réservations commencé "; break;
case "utente":  									$messaggio = "utilisateur"; break;
case "Interconnessioni":  							$messaggio = "Interconnexions"; break;
case "Assegnazione automatica disattivata":  		$messaggio = "Affectation automatique des réservations désactivée"; break;
case "Assegnazione automatica attivata":  			$messaggio = "Affectation automatique des réservations activée"; break;
case "Attiva":  									$messaggio = "Activer"; break;
case "Disattiva":  									$messaggio = "Désactiver"; break;
case "Scegli il tema grafico":  					$messaggio = "Choisir le thème graphique"; break;
case "Il tema grafico è stato cambiato":  			$messaggio = "Le thème graphique a été changé"; break;
case "Registrazione degli orari di entrata ed uscita attivata":				$messaggio = "Enregistrement des horaires d'entrée et sortie activé"; break;
case "Registrazione degli orari di entrata ed uscita disattivata":			$messaggio = "Enregistrement des horaires d'entrée et sortie désactivé"; break;
case "Le ore di differenza con l'orario del server sono state cambiate":	$messaggio = "Les heures de la différence avec celui du serveur ont été changées"; break;
case "Ore di differenza con l'orario del server": 	$messaggio = "Heures de différence avec l'heure du serveur"; break;
case "ora attuale":  								$messaggio = "heure courante"; break;
case "numero":  									$messaggio = "numéro"; break;
case "cognome cliente":  							$messaggio = "nom de famille du client"; break;
case "data iniziale":  								$messaggio = "date de début"; break;
case "data finale":  								$messaggio = "date de fin"; break;
case "Le colonne necessarie sono state cambiate":	$messaggio = "Les colonnes nécessaires ont été changées"; break;
case "Non mostrare prenotazioni che non hanno almeno una di queste colonne necessarie (non selezionarene per mostrare tutte)":	$messaggio = "Ne pas montrer les réservations qui n'ont pas au moins une de ces colonnes nécessaires (n'en choisissez aucune pour tout montrer)"; break;
case "cambia le colonne necessarie":  				$messaggio = "changer les colonnes nécessaires"; break;
case "Metodo di pagamento eliminato":				$messaggio = "méthode de paiement supprimée"; break;
case "Nuovo metodo di pagamento aggiunto":  		$messaggio = "Ajouter une nouvelle méthode de paiement"; break;
case "Metodi di pagamento":  						$messaggio = "Methodes de paiements "; break;
case "elimina":  									$messaggio = "supprimer"; break;
case "aggiungi":  									$messaggio = "ajouter"; break;
case "Quadro indicativo disponibilità":  	$messaggio = "Vue d'ensemble indicative de disponibilité"; break;
case "non mostrare":  				$messaggio = "ne pas montrer"; break;
case "Il modo di visualizzazione del quadro di disponibilità è stato cambiato":	$messaggio = "Le mode d'affichage de vue d'ensemble de disponibilité a été changé"; break;
case "Controllo disponibilità":  		$messaggio = "Contrôle des disponibilités"; break;
case "settimane di intervallo":  		$messaggio = "semaines d'intervalle"; break;
case "giorni di intervallo":  			$messaggio = "jours d'intervalle"; break;
case "Giorno di inizio/fine settimana cambiato":	$messaggio = "Jour de début/fin de semaine changé"; break;
case "Giorno di inizio/fine settimana nelle tabelle":	$messaggio = "Jour début/fin de semaine dans les tables"; break;
case "Anno":  					$messaggio = "Année"; break;
case "Creazione automatica del nuovo anno disattivata (importando i dati dall'anno precedente al primo login di un utente)": $messaggio = "Création automatique de nouvelle année désactivée (importation des données de l'année précédente à la première ouverture par tout utilisateur)"; break;
case "Creazione automatica del nuovo anno attivata (importando i dati dall'anno precedente al primo login di un utente)":	$messaggio = "Création automatique de nouvelle année activée (importation des données de l'année précédente à la première ouverture par tout utilisateur)"; break;
case "Creazione automatica nuovo anno disattivata":	$messaggio = "Création automatique de nouvelle année désactivée"; break;
case "Creazione automatica nuovo anno attivata":	$messaggio = "Création automatique de nouvelle année activée"; break;
case "Sostituisci la parola":  			$messaggio = "Remplacer le mot"; break;
case "Parole da sostituire":  			$messaggio = "Mots à remplacer"; break;
case "La parola da sostituire è stata aggiunta":	$messaggio = "Le mot à remplacer à été ajouté"; break;
case "La parola da sostituire è stata eliminata":	$messaggio = "Le mot à remplacer à été supprimé"; break;
case "modifica il documento":  			$messaggio = "modifier le document"; break;
case "Aggiungi ai documenti":  			$messaggio = "Ajouter les documents"; break;
case "variabili personalizzate":  		$messaggio = "variables personnalisées"; break;
case "Cambia il numero dei documenti":  	$messaggio = "Changer le nombre de documents"; break;
case "Il numero di documenti è stato cambiato":	$messaggio = "Le nombre de documents a été changé"; break;
case "Il numero di documenti è sbagliato":  	$messaggio = "Le nombre de documents est erroné"; break;
case "Indirizzo email":  			$messaggio = "Adresse e-mail"; break;
case "Mascherare la provenienza delle email sull'envelope":	$messaggio = "Masquer l'adresse de l'expéditeur lors des envois d'e-mail"; break;
case "Il mascheramento della provenienza delle email è stato cambiato":	$messaggio = "Le masquage de l'expéditeur des e-mail a été changé"; break;
case "SI":  					$messaggio = "OUI"; break;
case "NO":  					$messaggio = "NON"; break;
case "Cartelle in cui creare le pagine per il sito web":	$messaggio = "Répertoire où sont créées les pages pour le site web"; break;
case "percorsi separati da virgole relativi":	$messaggio = "chemins relatifs séparés par une virgule"; break;
case "alla cartella di HotelDruid, se non iniziano con /":	$messaggio = "vers le répertoire de HotelDruid, s`il ne commence pas par /"; break;
case "Non ho i permessi di scrittura sulla cartella":	$messaggio = "Je n'ai pas la permission d'écriture sur le répertoire"; break;
case "La cartella inserita <div style=\"display: inline; color: red;\">non esiste</div>":	$messaggio = "Le répertoire indiqué <div style=\"display: inline; color: red;\">n'existe pas</div>"; break;
case "Le cartelle dove vengono create le pagine per il sito web sono state cambiate":	$messaggio = "Les répertoires où sont sauvegardées les pages du site web ont été changés"; break;
case "Selezionare in modo predefinito":  	$messaggio = "Sélection par défaut"; break;
case "tutte le prenotazioni":  			$messaggio = "toutes les réservations"; break;
case "prenotazioni del periodo corrente":  	$messaggio = "réservations pour la période en cours"; break;
case "La selezione predefinita delle prenotazioni nella tabella con tutte le prenotazioni è stata cambiata":	$messaggio = "La sélection par défaut des réservations dans le tableau avec toutes les réservations a été modifiée"; break;
case "Numero di righe dopo cui ripetere la riga delle date":	$messaggio = "Nombre de lignes après qui faille répéter la ligne dates"; break;
case "Il numero  di righe dopo cui ripetere la riga delle date è stato cambiato":	$messaggio = "Le nombre de lignes après qui faille répéter la ligne dates a été modifié"; break;
case "orario entrata stimato":  		$messaggio = "heure d'arrivée estimée"; break;
case "Mostrare i giorni nella riga delle date?":	$messaggio = "Montrer les jours dans la ligne des dates ?"; break;
case "I giorni da mostrare nella tabella dei mesi sono stati cambiati":	$messaggio = "Les jours seront visibles dans la ligne date"; break;
case "Nazioni":  				$messaggio = "Pays"; break;
case "Elimina tutte":  				$messaggio = "Tout supprimer"; break;
case "Ripristina predefinite":  		$messaggio = "Restaurer les paramètres par défaut"; break;
case "Importa le nazioni":  			$messaggio = "Importer les pays"; break;
case "Regioni/provincie":  			$messaggio = "Départements"; break;
case "Importa le regioni/provincie":  		$messaggio = "Importer les départements"; break;
case "Nazione cancellata":  			$messaggio = "Pays supprimé"; break;
case "Regione/provincia cancellata":  		$messaggio = "Département supprimé"; break;
case "Nuova nazione aggiunta":  		$messaggio = "Nouveau pays ajouté"; break;
case "Nazioni predefinite ripristinate":  	$messaggio = "Pays par défaut restaurés"; break;
case "Nazioni cancellate":  			$messaggio = "Pays supprimés"; break;
case "Nazioni importate":  			$messaggio = "Pays importés"; break;
case "Nuova regione/provincia aggiunta":  	$messaggio = "Nouveau département ajouté"; break;
case "Regioni/provincie predefinite ripristinate":	$messaggio = "Départements par défaut restaurés"; break;
case "Regioni/provincie cancellate":  		$messaggio = "Départements supprimés"; break;
case "Regioni/provincie importate":  		$messaggio = "Départements importés"; break;
case "Parentele":  				$messaggio = "Lien de parenté"; break;
case "Importa le parentele":  			$messaggio = "Importer les liens de parenté"; break;
case "Parentela cancellata":  			$messaggio = "Liens de parenté supprimés"; break;
case "Nuova parentela aggiunta":  		$messaggio = "Nouveau lien de parenté ajouté"; break;
case "Parentele predefinite ripristinate":  	$messaggio = "Liens de parenté par défaut restaurés"; break;
case "Parentele cancellate":  			$messaggio = "Lien de parenté supprimé"; break;
case "Parentele importate":  			$messaggio = "Lien de parenté importé"; break;
case "origine":  				$messaggio = "origine"; break;
case "Origini delle prenotazioni":  		$messaggio = "Origine des réservations"; break;
case "Nuova origine delle prenotazioni aggiunta":	$messaggio = "Nouvelle origine des réservations ajoutée"; break;
case "Origine delle prenotazioni eliminata":  	$messaggio = "Origine des réservations supprimée"; break;
case "tutti gli utenti":  			$messaggio = "tous les utilisateurs"; break;
case "Personalizzazioni del gruppo":  		$messaggio = "Personnalisation du groupe"; break;
case "gruppo":  				$messaggio = "groupe"; break;
case "Log delle query di modifica generate":	$messaggio = "Fichier log des modification faites"; break;
case "da tutti gli utenti":  			$messaggio = "par tous les utilisateurs"; break;
case "dall'utente":  				$messaggio = "par l'utilisateur"; break;
case "dal gruppo":  				$messaggio = "par le groupe"; break;
case "attivato":				$messaggio = "activé"; break;
case "disattivato":				$messaggio = "désactivé"; break;
case "Vedi i log":  				$messaggio = "Voir le fichier log"; break;
case "Log delle query di modifica effettuate dagli utenti negli ultimi":	$messaggio = "Fichier log des modification faites par les utilisateurs dans les derniers"; break;
case "giorni":  				$messaggio = "jours"; break;
case "Utente":  				$messaggio = "Utilisateur"; break;
case "Query":  					$messaggio = "Demande"; break;
case "Cancella tutti i log":  			$messaggio = "Supprimer le fichier log"; break;
case "Log delle query di modifica degli utenti normali disattivato":	$messaggio = "Le fichier log des modifications des utilisateurs normaux est désactivé"; break;
case "Log delle query di modifica degli utenti normali attivato":	$messaggio = "Le fichier log des modification des utilisateurs normaux est activé"; break;
case "Allineare la disponibilità con la data di arrivo?":	$messaggio = "Aligner la disponibilité avec la date d'arrivée ?"; break;
case "L'allineamento dei giorni con la disponibilità nella tabella dei mesi è stato cambiato":	$messaggio = "L'alignement des jours avec la disponibilité des mois dans le tableau a été changé"; break;
case "Torna indietro":  			$messaggio = "Retour"; break;
case "Allineare la disponibilità con le date di arrivo potrebbe generare confusione ed errori sulle date di partenza, si è sicuri di voler continuare?":	$messaggio = "Aligner la disponibilité avec les dates d'arrivée pourrait prêter à confusion avec les dates de départ, êtes vous sûr de vouloir continuer ?"; break;
case "Documenti di identità":  			$messaggio = "Pièces d'identité"; break;
case "Tipo di documento di identità eliminato":	$messaggio = "Type de pièce d'identité supprimé"; break;
case "Nuovo tipo di documento di identità aggiunto":	$messaggio = "Nouveau type de document d'identité ajouté"; break;
case "Tipi di documento di identità predefiniti ripristinati":	$messaggio = "Types de pièces d'identité par défaut restaurés"; break;
case "Tipi di documento di identità cancellati":	$messaggio = "Types de pièces d'identité par défaut supprimés"; break;
case "Tipi di documento di identità importati":	$messaggio = "Types de pièces d'identité par défaut importés"; break;
case "Importa i documenti di identità":  	$messaggio = "Importer les pièces d'identité"; break;
case "Nuova nazione":  				$messaggio = "Nouveau pays"; break;
case "Nuova regione/provincia":  		$messaggio = "Nouveau département"; break;
case "Nuovo documento d'identità":  		$messaggio = "Nouveau document d'identité"; break;
case "Nuova parentela":  			$messaggio = "Nouvelle parenté"; break;
case "Elimina tutti":  				$messaggio = "Tout supprimer"; break;
case "Ripristina predefiniti":  		$messaggio = "Restaurer les paramètres par défaut"; break;
case "Città":  					$messaggio = "Villes"; break;
case "Nuova città":  				$messaggio = "Nouvelle ville"; break;
case "Importa le città":  			$messaggio = "Importer les villes"; break;
case "Città cancellata":  			$messaggio = "Ville supprimée"; break;
case "Nuova città aggiunta":  			$messaggio = "Nouvelle ville ajouté"; break;
case "Città predefinite ripristinate":  	$messaggio = "Villes par défaut restaurées"; break;
case "Città cancellate":  			$messaggio = "Villes supprimées"; break;
case "Città importate":  			$messaggio = "Villes importées"; break;
case "nella regione/provincia di":  		$messaggio = "dans le département de"; break;
case "nella nazione":  				$messaggio = "dans le pays"; break;
case "Titoli dei clienti":  			$messaggio = "Titre des clients"; break;
case "sesso":  					$messaggio = "sexe"; break;
case "m":  					$messaggio = "m"; break;
case "f":  					$messaggio = "f"; break;
case "Titolo dei clienti eliminato":  		$messaggio = "Titres des clients supprimés"; break;
case "Nuovo titolo dei clienti aggiunto":  	$messaggio = "Nouveau Titre de client ajouté"; break;
case "I dati della struttura sono stati cambiati":	$messaggio = "Les données de la structure ont été modifiés"; break;
case "Dati della struttura":  			$messaggio = "Données de l'entreprise"; break;
case "Nome":  					$messaggio = "Nom"; break;
case "Numero stelle":  				$messaggio = "Nombre d'étoiles"; break;
case "Nazione":  				$messaggio = "Pays"; break;
case "Comune":  				$messaggio = "Ville"; break;
case "Indirizzo":  				$messaggio = "Adresse"; break;
case "CAP":  					$messaggio = "Code postal"; break;
case "Telefono":  				$messaggio = "Téléphone"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Codice fiscale":  			$messaggio = "Code fiscal"; break;
case "Partita iva":  				$messaggio = "Numéro de TVA"; break;
case "Modifica i dati della struttura":  	$messaggio = "Modifier les données de l'entreprise"; break;
case "Clicca su un documento per modificarlo":	$messaggio = "Cliquer sur un document pour le modifier"; break;
case "Cambia l'ordine dei documenti":  		$messaggio = "Changer l'ordre des documents"; break;
case "Applica i cambiamenti":  			$messaggio = "Appliquer les modifications"; break;
case "ex":  					$messaggio = "ex"; break;
case "L'ordine dei documenti è stato cambiato":	$messaggio = "L'ordre des documents a été modifié"; break;
case "Sito web":  				$messaggio = "Site Web"; break;
case "Nome contatto":  				$messaggio = "Nom du contact"; break;
case "l'ordine delle tariffe è stato cambiato":	$messaggio = "l'ordre des tarifs a été changé"; break;
case "cambia l'ordine delle tariffe":  		$messaggio = "changer l'ordre des tarifs"; break;
case "valore predefinito a cui arrotondare le percentuali dei prezzi":	$messaggio = "valeur par défaut de l'arrondi du pourcentage des prix"; break;
case "il":  					$messaggio = "le"; break;
case "è stato cambiato":  			$messaggio = "a été changé"; break;
case "password per la visualizzazione dei dati delle carte di credito":	$messaggio = "mot de passe pour voir les données des cartes de crédit"; break;
case "attivata":  				$messaggio = "activé"; break;
case "disattivata":  				$messaggio = "désactivé"; break;
case "cambia la password":  			$messaggio = "changer le mot de passe"; break;
case "<b>Attenzione</b>: se si perde questa password non sarà più possibile leggere i dati delle carte di credito inserite":	$messaggio = "<b>Attention</b>: si vous perdez ce mot de passe vous ne pourrez plus lire les informations des cartes banacaires"; break;
case "nuova password":  			$messaggio = "nouveau mot de passe"; break;
case "ripetere password":  			$messaggio = "écrire à nouveau le mot de passe"; break;
case "attiva la password":  			$messaggio = "activer le mot de passe"; break;
case "le password inserite non coincidono":  	$messaggio = "les mots de passe ne correspondent pas"; break;
case "errore nelle funzioni ssl":  		$messaggio = "erreur dans les fonctions SSL"; break;
case "<b class=\"colred\">Attenzione</b>: tutti i dati delle carte di credito verranno cancellati":	$messaggio = "<b class=\"colred\">Attention</b>: toutes les données des cartes de crédit seront effacées"; break;
case "continua":  				$messaggio = "continuer"; break;
case "vecchia password":  			$messaggio = "ancien mot de passe"; break;
case "cambiata":  				$messaggio = "changé"; break;
case "piano":  					$messaggio = "étage"; break;
case "casa":  					$messaggio = "maison"; break;
case "2°":  					$messaggio = "2ème"; break;
case "3°":  					$messaggio = "3ème"; break;
case "2° codice":  				$messaggio = "2ème code"; break;
case "3° codice":  				$messaggio = "3ème code"; break;
case "Tabella con i documenti salvati":  	$messaggio = "Tableau avec les documents enregistrés"; break;
case "Il numero delle righe della tabella con i documenti salvati è stato cambiato":	$messaggio = "Le nombre de lignes de la table avec les documents enregistrés a été changé"; break;
case "valore a cui arrotondare le percentuali delle tasse":	$messaggio = "valeur d arrondi pour les pourcentages des taxes"; break;
case "documenti salvati":  			$messaggio = "documents enregistrés"; break;
case "Scegli le righe aggiuntive da mostrare":	$messaggio = "Choisissez les lignes supplémentaires à montrer"; break;
case "trasferito in cassa":  			$messaggio = "Transféré en caisse"; break;
case "cambia le righe":  			$messaggio = "changer les lignes"; break;
case "Le righe aggiuntive sono state cambiate":	$messaggio = "les lignes supplémentaires ont été changés"; break;
case "soldi prenotazioni cancellate":  		$messaggio = "argent des réservations supprimées"; break;
case "cognome ospite se differente":  		$messaggio = "nom de l`hôte si elle est différente"; break;
case "Ragione sociale":  			$messaggio = "Raison sociale"; break;
case "URL del logo":  				$messaggio = "URL du logo"; break;
case "Nome delle unità da affittare":  		$messaggio = "Nom de l`unité de location"; break;
case "nome personalizzato":  			$messaggio = "nom personnalisé"; break;
case "singolare":  				$messaggio = "singulier"; break;
case "plurale":  				$messaggio = "pluriel"; break;
case "genere":  				$messaggio = "genre"; break;
case "m":  					$messaggio = "m"; break;
case "f":  					$messaggio = "f"; break;
case "Il nome delle unità da affittare è stato cambiato":	$messaggio = "Le nom de l`unité de location a été changé"; break;
case "Tabelle con le casse":  			$messaggio = "Tableau avec les caisses"; break;
case "Il numero delle righe delle tabelle con le casse è stato cambiato":	$messaggio = "Le nombre de lignes des tableaux avec les cassettes a été changé"; break;
case "Elimina il documento":  			$messaggio = "Supprimer le document"; break;
case "Sei sicuro di voler eliminare il documento":	$messaggio = "Êtes-vous sûr de vouloir supprimer le document"; break;
case "Il documento è stato eliminato":	$messaggio = "Le document a été supprimé"; break;
case "Campi da considerare per la ricerca dei clienti":	$messaggio = "Les champs à considérer lors de la recherche des clients"; break;
case "cognome":  				$messaggio = "nom"; break;
case "email":  					$messaggio = "e-mail"; break;
case "nome":  					$messaggio = "prénom"; break;
case "telefono":  				$messaggio = "téléphone"; break;
case "città":  					$messaggio = "ville"; break;
case "indirizzo":  				$messaggio = "adresse"; break;
case "codice postale":  			$messaggio = "code postal"; break;
case "I campi da considerare per la ricerca dei clienti sono stati cambiati":	$messaggio = "Les champs à considérer lors de la recherche des clients ont été modifiés"; break;
case "Documenti":  				$messaggio = "Documents"; break;
case "documento":  				$messaggio = "document"; break;
case "Nome combinazione":  			$messaggio = "Combination name"; break;
case "prenotazioni correnti e future":  	$messaggio = "current and future reservations"; break;
case "Personalizzazioni di <b>tutti gli utenti</b>":  	$messaggio = "Customizations of <b>all users</b>"; break;
case "Data":  					$messaggio = "Date"; break;
case "codice":  				$messaggio = "code"; break;
case "Tipo":  					$messaggio = "Type"; break;
case "Documento":  				$messaggio = "Document"; break;
case "tariffa":  				$messaggio = "rate"; break;
case "commissioni":  				$messaggio = "commissions"; break;
case "resto commissioni":  			$messaggio = "commissions rest"; break;
case "tasse":  					$messaggio = "taxes"; break;
case "totale":  				$messaggio = "total"; break;
case "Nome delle unità singole":  		$messaggio = "Name of single units"; break;
case "Tabella dei messaggi":  			$messaggio = "Messages table"; break;
case "Il numero di righe della tabella dei messaggi è stato cambiato":	$messaggio = "The number of rows of the messages table has been changed"; break;
case "Scarica le email di richiesta disponibiltà dal server di posta":	$messaggio = "Download emails for availability enquiries from mail server"; break;
case "per es.":  				$messaggio = "e.g."; break;
case "Protocollo":  				$messaggio = "Protocol"; break;
case "Porta":  					$messaggio = "Port"; break;
case "default":  				$messaggio = "default"; break;
case "persoalizzata":  				$messaggio = "custom"; break;
case "Nome utente":  				$messaggio = "Username"; break;
case "Password":  				$messaggio = "Password"; break;
case "lasciare vuota per chiedere ogni volta":	$messaggio = "leave empty to ask each time"; break;
case "Identificazione messaggi di richiesta":	$messaggio = "Enquiry messages identification"; break;
case "Messaggio iniziale":  			$messaggio = "First post"; break;
case "Qualsiasi messaggio":  			$messaggio = "Any post"; break;
case "da":  					$messaggio = "from"; break;
case "con oggetto contenete":  			$messaggio = "with subject containing"; break;
case "I dati per lo scaricamento delle email sono sbagliati o incompleti":	$messaggio = "The data to download emails are wrong or incomplete"; break;
case "Lo scaricamento delle email di richiesta disponibiltà dal server di posta è stato cambiato":	$messaggio = "The download of emails for availability enquiries from mail server has been changed"; break;
case "Colori delle prenotazioni":  		$messaggio = "Reservations colors"; break;
case "Tutto pagato":  				$messaggio = "All paid"; break;
case "Caparra pagata":  			$messaggio = "Deposit paid"; break;
case "Confermate":  				$messaggio = "Confirmed"; break;
case "Non confermate":  			$messaggio = "Not confirmed"; break;
case "I colori sono sbagliati":  		$messaggio = "Colors are wrong"; break;
case "I colori delle prenotazioni sono stati cambiati":	$messaggio = "Reservations colors have been changed"; break;
case "Campi personalizzati dei clienti":  	$messaggio = "Custom fields for clients"; break;
case "Nuovo campo personalizzato dei clienti aggiunto":	$messaggio = "New custom field for clients added"; break;
case "Campo personalizzato dei clienti eliminato":	$messaggio = "Custom field for clients deleted"; break;
case "tipo":  					$messaggio = "type"; break;
case "booleano":  				$messaggio = "boolean"; break;
case "testo":  					$messaggio = "text"; break;
case "Il campo personalizzato contiene caratteri non consentiti":	$messaggio = "The custom field contains not allowed characters"; break;
case "Gestire anche i codici CVC delle carte di credito":	$messaggio = "Manage the CVC codes from credit cards too"; break;
case "Esonero di responsabilità":  		$messaggio = "Disclaimer"; break;
case "la gestione dei codici CVC avverrà sotto la propria responsabilità, essendo a conoscenza che gli standard di sicurezza PCI ne vietano la registrazione":	$messaggio = "the CVC codes will be managed under your own responsibility, being aware that PCI security standards forbid their storage"; break;
case "L'accettazione di questa clausola conferma che gli sviluppatori di questo software sono liberi da ogni responsibilità sulla sicurezza di questi dati":	$messaggio = "Accepting this clause confirms that the developers of this software are free from all responsibilities regarding the security of these data"; break;
case "Accetto":  				$messaggio = "I Accept"; break;
case "Declino":  				$messaggio = "I Decline"; break;
case "La gestione dei codici cvc è stata cambiata":	$messaggio = "The management of CVC codes has been changed"; break;
case "Scegli le righe con i totali da mostrare":	$messaggio = "Choose which totals to show in rows"; break;
case "giornaliero":  				$messaggio = "daily"; break;
case "mensile":  				$messaggio = "montly"; break;
case "tabella":  				$messaggio = "table"; break;
case "Le righe da mostrare nelle tabelle delle casse sono state cambiate":	$messaggio = "Rows shown in cashobxes tables have been changed"; break;
case "partenze e prenotazioni correnti":  	$messaggio = "departures and current reservations"; break;
case "Commenti personalizzati delle prenotazioni":	$messaggio = "Custom comments for reservations"; break;
case "Commento personalizzato della prenotazione eliminato":	$messaggio = "Custom comment for reservation deleted"; break;
case "Nuovo commento personalizzato della prenotazione aggiunto":	$messaggio = "New custom comment for reservation added"; break;
case "Punto vendita ed inventario":  		$messaggio = "Point of sale and inventory"; break;
case "Ordinamento nell'inventario e punto vendita":	$messaggio = "Sorting in inventory and point of sale"; break;
case "alfabetico":  				$messaggio = "alphabetically"; break;
case "per ordine di inserimento":  		$messaggio = "by insertion order"; break;
case "Tasti per operazioni nel punto vendita":	$messaggio = "Buttons for operations in point of sale"; break;
case "L'ordinamento nell'inventario e nel punto vendita è stato cambiato":	$messaggio = "Sorting in inventory and point of sale has been changed"; break;
case "I tasti per operazioni nel punto vendita sono stati cambiati":	$messaggio = "Buttons for operations in point of sale have been changed"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "i link per l'esportazione dei calendari in formato ical sono cambiati, ricordarsi di aggiornarli sui calendari esterni":	$messaggio = "the links to export calendars in ical format have changed, remember to update them on external calendars"; break;
case "La tariffa":  				$messaggio = "Rate"; break;
case "è ancora in uso nelle interconnessioni":	$messaggio = "is still in use in interconnections"; break;
case "almeno 8 caratteri, con lettere e numeri o simboli":	$messaggio = "at least 8 characters, with letters and numbers or symbols"; break;
case "diversa dalle ultime":  			$messaggio = "different from last"; break;
case "Condizioni Generali di Contratto":  	$messaggio = "General Terms and Conditions"; break;
case "del servizio di memorizzazione delle carte di credito":	$messaggio = "of the credit cards storage service"; break;
case "La password non è stata modificata":  	$messaggio = "The password has not been modified"; break;
case "password errata":  			$messaggio = "wrong password"; break;
case "adulto":  				$messaggio = "adult"; break;
case "adulti":  				$messaggio = "adults"; break;
case "bambino":  				$messaggio = "child"; break;
case "bambini":  				$messaggio = "children"; break;
case "Numero di tipologie di persone":  	$messaggio = "Number of people types"; break;
case "Tipologia":  				$messaggio = "Type"; break;
case "Può essere ospite principale":  		$messaggio = "Can be main guest"; break;
case "Prezzo in percentuale del prezzo per persona":	$messaggio = "Price in percentage of per person price"; break;
case "arrotondato a":  				$messaggio = "rounded to"; break;
case "Modifica le tipologie di persone":  	$messaggio = "Modify people types"; break;
case "Il numero di tipologie di persone è sbagliato":	$messaggio = "The number of people types is wrong"; break;
case "Il numero di tipologie di persone è stato cambiato":	$messaggio = "The number of people types has been changed"; break;
case "I dati inseriti non sono corretti":  	$messaggio = "Inserted data are incorrect"; break;
case "Le tipologie di persone sono state modificate":	$messaggio = "The people types have been modified"; break;
case "Cambia per tutti gli utenti":  		$messaggio = "Change for all users"; break;
case "Modifica le tipologie di persone per tutti gli utenti":	$messaggio = "Modify people types for all users"; break;
case "tipi di persona":  			$messaggio = "person types"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>